{{ appname }} assets
================================================================================

Files in this directory are not version controlled. They are ignored by
`../.gitignore`.

This folder is typically synced from shared drives such as Google Drive,
Dropbox, Seafile, etc.


Folder structure
--------------------------------------------------------------------------------

We recommend creating sub-folders as follows:

- `assets/img/`     has images
- `assets/data/`    has data files (e.g. topoJSON maps, XLSX, CSV, SQLite files)
- `assets/fonts/`   has custom fonts (if required)
